/* Copyright (C) 2010 Nikos Chantziaras.
 *
 * This file is part of the QTads program.  This program is free software; you
 * can redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation; either version
 * 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; see the file COPYING.  If not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/* ChangeLog:
 *     2002/12/17 Niko  - Creation
 */

#include "std.h"
#include "globals.h"

char G_tads_oem_app_name[] = "QTads "QTADS_VERSION;
char G_tads_oem_dbg_name[] = ""; /* No debugger for Qt (yet). */
char G_tads_oem_display_mode[] = "multimedia";
char G_tads_oem_author[] =
    "QTads copyright (c) 2003, 2012 by Nikos Chantziaras <realnc@gmail.com>\n";
int G_tads_oem_copyright_prefix = TRUE;
